timeintervaltools.split_intervals_at_rationals
==============================================

.. autofunction:: abjad.tools.timeintervaltools.split_intervals_at_rationals.split_intervals_at_rationals
